"use strict";
/********************************************************************************
 * Copyright (C) 2019 Uni Sayo and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var EMPTY_ELEMENTS = [
    'area',
    'base',
    'br',
    'col',
    'embed',
    'hr',
    'img',
    'input',
    'keygen',
    'link',
    'menuitem',
    'meta',
    'param',
    'source',
    'track',
    'wbr'
];
function registerLanguageConfigurations() {
    var htmlConfiguration = require('../../../languages/vue-html-language-configuration.json');
    monaco.languages.setLanguageConfiguration('vue-html', __assign({}, htmlConfiguration, { wordPattern: /(-?\d*\.\d\w*)|([^\`\~\!\@\$\^\&\*\(\)\=\+\[\{\]\}\\\|\;\:\'\"\,\.\<\>\/\s]+)/g, onEnterRules: [
            {
                beforeText: new RegExp("<(?!(?:" + EMPTY_ELEMENTS.join('|') + "))([_:\\w][_:\\w-.\\d]*)([^/>]*(?!/)>)[^<]*$", 'i'),
                afterText: /^<\/([_:\w][_:\w-.\d]*)\s*>$/i,
                action: { indentAction: monaco.languages.IndentAction.IndentOutdent }
            },
            {
                beforeText: new RegExp("<(?!(?:" + EMPTY_ELEMENTS.join('|') + "))(\\w[\\w\\d]*)([^/>]*(?!/)>)[^<]*$", 'i'),
                action: { indentAction: monaco.languages.IndentAction.Indent }
            }
        ] }));
    var pugConfiguration = require('../../../languages/vue-pug-language-configuration.json');
    monaco.languages.setLanguageConfiguration('vue-pug', __assign({}, pugConfiguration, { wordPattern: /(-?\d*\.\d\w*)|([^\`\~\!\@\$\^\&\*\(\)\=\+\[\{\]\}\\\|\;\:\'\"\,\.\<\>\/\s]+)/g, onEnterRules: [
            {
                beforeText: new RegExp("<(?!(?:" + EMPTY_ELEMENTS.join('|') + "))([_:\\w][_:\\w-.\\d]*)([^/>]*(?!/)>)[^<]*$", 'i'),
                afterText: /^<\/([_:\w][_:\w-.\d]*)\s*>$/i,
                action: { indentAction: monaco.languages.IndentAction.IndentOutdent }
            },
            {
                beforeText: new RegExp("<(?!(?:" + EMPTY_ELEMENTS.join('|') + "))(\\w[\\w\\d]*)([^/>]*(?!/)>)[^<]*$", 'i'),
                action: { indentAction: monaco.languages.IndentAction.Indent }
            }
        ] }));
    var postcssConfiguration = require('../../../languages/vue-postcss-language-configuration.json');
    monaco.languages.setLanguageConfiguration('vue-postcss', postcssConfiguration);
}
exports.registerLanguageConfigurations = registerLanguageConfigurations;
function registerLanguage() {
    monaco.languages.register({
        id: 'vue-html',
        aliases: [
            'Vue-html'
        ]
    });
    monaco.languages.register({
        id: 'vue-postcss',
        aliases: [
            'Vue-postcss'
        ]
    });
    monaco.languages.register({
        id: 'vue-pug',
        aliases: [
            'Vue-pug'
        ]
    });
}
exports.registerLanguage = registerLanguage;
//# sourceMappingURL=languages.js.map