/********************************************************************************
 * Copyright (C) 2019 Uni Sayo and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { interfaces } from 'inversify';
import { PreferenceProxy, PreferenceService, PreferenceSchema, PreferenceChangeEvent } from '@devpodio/core/lib/browser/preferences';
interface FormatterConfiguration {
    prettier: object;
    /** Base directory of this build.  */
    prettyhtml: {
        printWidth: number;
        singleQuote: boolean;
        wrapAttributes: boolean;
        sortAttributes: boolean;
    };
    /** List of commands for this build configuration.  */
    'js-beautify-html': object;
}
export declare const vuePreferenceSchema: PreferenceSchema;
export interface VueConfiguration {
    'vue.format.enable': boolean;
    'vetur.useWorkspaceDependencies': boolean;
    'vetur.completion.autoImport': boolean;
    'vetur.completion.useScaffoldSnippets': boolean;
    'vetur.completion.tagCasing': 'initial' | 'kebab';
    'vetur.validation.template': boolean;
    'vetur.validation.style': boolean;
    'vetur.validation.script': boolean;
    'vetur.format.options.tabSize': number;
    'vetur.format.options.useTabs': boolean;
    'vetur.format.defaultFormatter.html': 'none' | 'prettyhtml' | 'js-beautify-html' | 'prettier';
    'vetur.format.defaultFormatter.css': 'none' | 'prettier';
    'vetur.format.defaultFormatter.postcss': 'none' | 'prettier';
    'vetur.format.defaultFormatter.scss': 'none' | 'prettier';
    'vetur.format.defaultFormatter.less': 'none' | 'prettier';
    'vetur.format.defaultFormatter.stylus': 'none' | 'stylus-supremacy';
    'vetur.format.defaultFormatter.js': 'none' | 'prettier' | 'prettier-eslint' | 'vscode-typescript';
    'vetur.format.defaultFormatter.ts': 'none' | 'prettier' | 'vscode-typescript';
    'vetur.format.defaultFormatterOptions': FormatterConfiguration;
    'vetur.format.styleInitialIndent': boolean;
    'vetur.format.scriptInitialIndent': boolean;
    'vetur.trace.server': 'off' | 'messages' | 'verbose';
}
export declare type VuePreferenceChange = PreferenceChangeEvent<VueConfiguration>;
export declare const VuePreferences: unique symbol;
export declare type VuePreferences = PreferenceProxy<VueConfiguration>;
export declare function createVuePreferences(preferences: PreferenceService): VuePreferences;
export declare function bindVuePreferences(bind: interfaces.Bind): void;
export {};
//# sourceMappingURL=vue-preferences.d.ts.map